@@ -3,7 +3,7 @@ BEGIN {
   $Vim::X::AUTHORITY = 'cpan:YANICK';
 }
 # ABSTRACT: Candy for Perl programming in Vim
-$Vim::X::VERSION = '1.0.1';
+$Vim::X::VERSION = '1.1.0';
 use strict;
 use warnings;
 
@@ -14,17 +14,21 @@ use parent 'Exporter';
 
 our @EXPORT = qw/ 
     vim_func vim_prefix vim_msg vim_buffer vim_cursor vim_window
+    vim_current_file
     vim_command
+    vim_expand
     vim_call
     vim_lines
     vim_append
     vim_eval
     vim_range
     vim_line
+    vim_input
 vim_delete /;
 
 use Vim::X::Window;
 use Vim::X::Buffer;
+use Vim::X::Cursor;
 use Vim::X::Line;
 
 sub import {
@@ -54,7 +58,9 @@ sub Vim :ATTR_SUB {
     no strict 'refs';
     VIM::DoCommand(<<END);
 function $name($args) $range
-    perl ${class}::$name( split "\\n", scalar VIM::Eval('a:000'))
+    perl \$Vim::X::RETURN = ${class}::$name( split "\\n", scalar VIM::Eval('a:000'))
+    perl vim_command( "let vimx_return = '\$Vim::X::RETURN'" )
+    return vimx_return
 endfunction
 END
 
@@ -143,23 +149,33 @@ sub vim_buffer {
 }
 
 
+sub vim_current_file {
+    my $symbol = '%' . ( ':p' x ! shift );
+
+    my $r = vim_expand( $symbol ) or return;
+
+    return Path::Tiny::path( $r ); 
+}
+
+
 sub vim_lines {
     vim_buffer->lines(@_);
 }
 
 
 sub vim_line {
-    @_ ? vim_buffer->line(shift) : vim_cursor();
+    @_ ? vim_buffer->line(shift) : vim_cursor()->line;
 }
 
 
 sub vim_append {
-    vim_cursor()->append(@_);
+    vim_cursor()->line->append(@_);
 }
 
 
 sub vim_eval {
-    return map { scalar VIM::Eval($_) } @_;
+    my @results = map { scalar VIM::Eval($_) } @_;
+    return wantarray ? @results : $results[0];
 }
 
 
@@ -173,7 +189,8 @@ sub vim_range {
 
 
 sub vim_command {
-    return map { VIM::DoCommand($_) } @_;
+    my @results = map { VIM::DoCommand($_) } @_;
+    return wantarray ? @results : $results[0];
 }
 
 
@@ -184,6 +201,23 @@ sub vim_call {
 }
 
 
+sub vim_expand {
+    my @mapped = map { vim_eval( "expand('$_')" ) } @_;
+    return wantarray ? @mapped : $mapped[0];
+}
+
+
+sub vim_input {
+    my @args = @_;
+    s/"/\\"/g for @args;
+
+    my $args = join ',', map { qq{"$_"} } @args;
+
+    vim_command( "let l = input($args)" );
+    return vim_eval("l");
+}
+
+
 sub vim_window {
     return Vim::X::Window->new( _window => shift || $::curwin);
 }
@@ -213,7 +247,7 @@ Vim::X - Candy for Perl programming in Vim
 
 =head1 VERSION
 
-version 1.0.1
+version 1.1.0
 
 =head1 SYNOPSIS
 
@@ -396,6 +430,12 @@ Display the strings of I<@text> concatenated as a vim message.
 Returns the L<Vim::X::Buffer> object associated with the I<$i>th buffer. If
 I<$i> is not given or set to '0', it returns the current buffer.
 
+=head2 vim_current_file($local)
+
+Returns the file associated with the current buffer as a L<Path::Tiny>
+object. If C<$local> is true the path will be relative to the directory
+where C<vim> was launched, otherwise it'll be absolute.
+
 =head2 vim_lines( @indexes )
 
 Returns the L<Vim::X::Line> objects for the lines in I<@indexes> of the
@@ -447,6 +487,18 @@ provided arguments.
     #    :call SetVersion( '1.23' )
     # in vim
 
+=head2 vim_expand( @expressions )
+
+Returns the expansion of the passed expression(s).
+
+    my $current_file = vim_expand( '%' );
+    my ( $local, $absolute) = vim_expand( '%', '%:p' );
+
+=head2 vim_input( $prompt, $default, $completion_arg )
+
+Prompts the user for some value. The arguments are the same
+as for vim's own C<input>.
+
 =head2 vim_window( $i )
 
 Returns the L<Vim::X::Window> associated with the I<$i>th window. If I<$i>
@@ -454,7 +506,7 @@ is not provided or is zero, returns the object for the current window.
 
 =head2 vim_cursor
 
-Returns the L<Vim::X::Line> associated with the position of the cursor
+Returns the L<Vim::X::Cursor> associated with the position of the cursor
 in the current window.
 
 =head2 vim_delete( @lines ) 
