@@ -3,7 +3,7 @@ BEGIN {
   $Vim::X::Range::AUTHORITY = 'cpan:YANICK';
 }
 # ABSTRACT: A range of lines in a Vim buffer
-$Vim::X::Range::VERSION = '1.0.1';
+$Vim::X::Range::VERSION = '1.1.0';
 use Moo;
 
 use overload 
@@ -11,10 +11,7 @@ use overload
         my $self = shift;
         return $self->lines;
     },
-    '""' => sub {
-        my $self = shift;
-        return join "\n", $self->lines;
-    };
+    '""' => \&as_string;
 
 
 
@@ -53,6 +50,12 @@ sub replace {
 }
 
 
+sub as_string {
+    my $self = shift;
+    return join "\n", $self->lines;
+}
+
+
 sub from_rewind {
     my( $self, $condition ) = @_;
     my( $from ) = $self->lines;
@@ -104,7 +107,7 @@ Vim::X::Range - A range of lines in a Vim buffer
 
 =head1 VERSION
 
-version 1.0.1
+version 1.1.0
 
 =head1 DESCRIPTION
 
@@ -134,6 +137,10 @@ C<to> value of the object will be updated in consequence.
 
 Returns itself.
 
+=head2 as_string 
+
+Returns the range as a string.
+
 =head1 AUTHOR
 
 Yanick Champoux <yanick@cpan.org>
