@@ -3,7 +3,7 @@ BEGIN {
   $Vim::X::Window::AUTHORITY = 'cpan:YANICK';
 }
 # ABSTRACT: A window in Vim
-$Vim::X::Window::VERSION = '1.0.1';
+$Vim::X::Window::VERSION = '1.1.0';
 use strict;
 use warnings;
 
@@ -29,8 +29,13 @@ sub buffer {
 sub cursor {
     my $win = shift;
     my @cursor = $win->_window->Cursor;
-    return wantarray ? @cursor
-        : Vim::X::Line->new( buffer => $win->buffer, index => $cursor[0] );
+
+    return Vim::X::Cursor->new(
+        window => $win,
+        line => Vim::X::Line->new( buffer => $win->buffer, index =>
+            $cursor[0]),
+        col => $cursor[1]
+    );
 }
 
 1;
@@ -47,7 +52,7 @@ Vim::X::Window - A window in Vim
 
 =head1 VERSION
 
-version 1.0.1
+version 1.1.0
 
 =head1 FUNCTIONS
 
@@ -57,9 +62,7 @@ Returns the buffer associated with the window as a .L<Vim::X::Buffer> object
 
 =head2 cursor() 
 
-Returns the cursor position in the window. 
-In list context, returns the I<(line,colum)> coordinates. In scalar
-context, the line as a L<Vim::X::Line> object.
+Returns the cursor position in the window as a L<Vim::X::Cursor> object. 
 
 =head1 AUTHOR
 
